import { getGenres, getPubs, getPubsWithGenres, getResponses, getStories, getStoriesWithGenres, getSubsComplete } from "app/lib/get"
import { DataTable } from "app/ui/tables/data-table"
import { columns } from "./columns"
import { Genre, Pub, Response, Story, Sub } from "@prisma/client"
import CreateSubmissionDialog from "./create"
import { PubWithGenres } from "app/publication/page"
import { StoryWithGenres } from "app/story/page"

export type SubComplete = Sub & {
  pub: Pub,
  story: Story,
  response: Response
}
export default async function Page() {

  const subs: Array<SubComplete> = await getSubsComplete()
  const stories: StoryWithGenres[] = await getStoriesWithGenres()
  const pubs: PubWithGenres[] = await getPubsWithGenres()
  const responses: Response[] = await getResponses()
  const genres: Genre[] = await getGenres()

  return (
    <div className="container px-1 md:px-4 mx-auto">
      <DataTable data={subs} columns={columns} tableName="sub"
        stories={stories}
        pubs={pubs}
        responses={responses}
        genres={genres}
      >
        <CreateSubmissionDialog
          stories={stories}
          pubs={pubs}
          responses={responses}
        />
      </DataTable>
    </div>
  )
}
